@@ -316,15 +316,82 @@ class TestBuildWatch(TestWatch):
         state = self.watch(build)[-1]
         assert "with status message 'failed to foo the bar'" in state.message
 
-    def test_watch_not_completed(self, build):
+    def test_watch_not_completed(self, build, mocker):
         build.status["build_status"] = None
         build.status["tuxbuild_status"] = "error"
         build.status["status_message"] = "the infrastructure failed"
+        mocker.patch("tuxbuild.build.Build.build")
         state = self.watch(build)[-1]
         assert state.state != "completed"
         assert state.status is None
         assert "the infrastructure failed" in state.message
 
+    def test_retries_on_errors(self, build, mocker):
+        build_build = mocker.patch("tuxbuild.build.Build.build")
+        build.status["build_status"] = None
+        build.status["tuxbuild_status"] = "error"
+        build.status["status_message"] = "the infrastructure failed"
+        states = self.watch(build)
+        assert build_build.call_count == 2
+        assert [state.state for state in states] == [
+            "queued",
+            "building",
+            "error",
+            "queued",
+            "building",
+            "error",
+            "queued",
+            "building",
+            "error",
+        ]
+
+    def test_retry_succeeds_in_the_second_attempt(self, build, mocker, get_status):
+        statuses = iter(
+            [
+                {
+                    "tuxbuild_status": "queued",
+                },
+                {
+                    "tuxbuild_status": "building",
+                },
+                {
+                    "tuxbuild_status": "error",
+                },
+                {
+                    "tuxbuild_status": "queued",
+                },
+                {
+                    "tuxbuild_status": "building",
+                },
+                {
+                    "tuxbuild_status": "complete",
+                    "build_status": "pass",
+                    "warnings_count": 0,
+                    "errors_count": 0,
+                },
+            ]
+        )
+
+        def __get_status__():
+            nonlocal build
+            nonlocal statuses
+            build.status = next(statuses)
+
+        get_status.side_effect = __get_status__
+        build_build = mocker.patch("tuxbuild.build.Build.build")
+        mocker.patch("time.sleep")
+
+        states = self.watch(build)
+        assert build_build.call_count == 1
+        assert [state.state for state in states] == [
+            "queued",
+            "building",
+            "error",
+            "queued",
+            "building",
+            "complete",
+        ]
+
     def test_output_with_multiple_kconfigs(self, build):
         build.kconfig = ["defconfig", "https://raw.foo.com/kconfig/myconfig.txt"]
         assert "(defconfig+1)" in str(build)
