@@ -169,25 +169,43 @@ class Build:
             )
 
     def watch(self):
-        waiting_states = [
-            BuildState(
-                build=self,
-                state="queued",
-                message="Queued",
-                icon="⏳",
-                cli_color="white",
-            ),
-            BuildState(
-                build=self,
-                state="building",
-                message="Building",
-                icon="⚗️ ",
-                cli_color="cyan",
-            ),
-        ]
-        for state in waiting_states:
-            yield state
-            self.wait_on_status(state.state)
+        attempts = 1
+        max_attempts = 3
+        while True:
+            waiting_states = [
+                BuildState(
+                    build=self,
+                    state="queued",
+                    message="Queued",
+                    icon="⏳",
+                    cli_color="white",
+                ),
+                BuildState(
+                    build=self,
+                    state="building",
+                    message="Building",
+                    icon="⚗️ ",
+                    cli_color="cyan",
+                ),
+            ]
+            for state in waiting_states:
+                yield state
+                self.wait_on_status(state.state)
+
+            if self.status["tuxbuild_status"] == "error" and attempts < max_attempts:
+                attempts += 1
+                message = self.status.get("status_message", "infrastructure error")
+                yield BuildState(
+                    build=self,
+                    state=self.status["tuxbuild_status"],
+                    message=message
+                    + f" - retrying (attempt {attempts}/{max_attempts})",
+                    icon="🔧",
+                    cli_color="yellow",
+                )
+                self.build()
+            else:
+                break
 
         errors = 0
         warnings = 0
