@@ -6,7 +6,6 @@ from os.path import expanduser
 import configparser
 import re
 import yaml
-import time
 from tuxbuild import requests
 
 
@@ -116,16 +115,11 @@ class Config:
     def check_auth_token(self):
         headers = {"Content-type": "application/json", "Authorization": self.auth_token}
         url = self.kbapi_url + "/verify"
-        attempts = 6
-        for i in range(1, attempts + 1):
-            r = requests.get(url, headers=headers)
-            if r.status_code == 200:
-                return
-            elif r.status_code // 500 == 1:
-                if i < attempts:
-                    time.sleep(2 ** i)  # exponential backoff
-            else:
-                r.raise_for_status()  # Some unexpected status that's not caught
+        r = requests.get(url, headers=headers)
+        if r.status_code == 200:
+            return
+        else:
+            r.raise_for_status()  # Some unexpected status that's not caught
 
 
 InvalidConfiguration = tuxbuild.exceptions.InvalidConfiguration
@@ -176,5 +170,7 @@ class BuildSetConfig:
     def __fetch_remote_config__(self, url):
         result = requests.get(url)
         if result.status_code != 200:
-            raise InvalidConfiguration(f"Unable to retrieve {url}: {result.reason}")
+            raise InvalidConfiguration(
+                f"Unable to retrieve {url}: {result.status_code} {result.reason}"
+            )
         return result.text
